.. _contributing:

Contributing to ``datalad-next``
********************************

We're happy about contributions of any kind to this project - thanks for considering making one!

Please take a look at `CONTRIBUTING.md <https://github.com/datalad/datalad-next/blob/main/CONTRIBUTING.md>`_ for an overview of development principles and common questions, and `get in touch <https://github.com/datalad/datalad-next/issues/new>`_ in case of questions or to discuss features, bugs, or other issues.